Skip to contents

Mask data around a bednet event

Usage

mask_bn_event(i, xds_obj, daysb4 = 0, days_after = 365)

Arguments

i

the index of the event to mask

xds_obj

a ramp.xds model object

daysb4

the number of days before the event to mask

days_after

the number of days after the event to mask